import type {
  Rule,
  RuleConfig,
  RuleConfigQuality,
  UserConfig as BaseUserConfig,
  QualifiedConfig as BaseQualifiedConfig
} from '@commitlint/types';

declare const plugin: { rules: Record<string, Rule<any>> };
export default plugin;

export type RulesConfig<V = RuleConfigQuality.User> = {
  '@pega/multi-scope-enum': RuleConfig<
    V,
    void | { scopes?: string[]; separator?: string | RegExp; trim?: boolean }
  >;
  '@pega/header-reference': RuleConfig<V>;
  '@pega/reference-action-enum': RuleConfig<
    V,
    void | { actions?: string[]; caseSensitive?: boolean }
  >;
  '@pega/reference-order': RuleConfig<V, void | { prefixes?: string[]; ascending?: boolean }>;
  '@pega/subject-present-tense': RuleConfig<V, void | { ignorePrefixes?: string[] }>;
  '@pega/agile-studio': RuleConfig<V, void | { prefixes?: string[] }>;
  '@pega/open-agile': RuleConfig<V, void | { prefixes?: string[] }>;
  '@pega/merge-commit': RuleConfig<V>;
  '@pega/revert-commit': RuleConfig<V>;
  '@pega/spellcheck': RuleConfig<V, void | { ignorePrefixes?: string[] }>;
};

export type UserConfig = BaseUserConfig & {
  rules?: Partial<RulesConfig>;
};

export type QualifiedConfig = BaseQualifiedConfig & {
  rules: Partial<RulesConfig<RuleConfigQuality.Qualified>>;
};
